@@ -4,7 +4,7 @@ use Mojo::ByteStream 'b';
 use Mojo::Collection 'c';
 use Mojo::URL;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 # Cache for generated CSS and JavaScript
 has [qw/js css pattern_rotate/];
@@ -217,7 +217,10 @@ sub register {
           c(@post)->join->xml_escape;
       }
       else {
-        $str .= ';' . int(rand(50)) . '">' . $text->();
+        unless ($plugin->{no_inline}) {
+          $str .= ';' . int(rand(50));
+        };
+        $str .= '">' . $text->();
       };
 
       $str .= '</a>';
@@ -322,7 +325,7 @@ sub register {
       i=>i.addEventListener(
         "click",function(e){
           e.preventDefault();
-          ${method_name}(false,this.href=='#'?this.href:this.getAttribute('data-href'))
+          ${method_name}(false,this.href=='#'?this.getAttribute('data-href'):this.href)
         }
       )
     )
